@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,42 +14,42 @@ AbstractDisplayInfo::AbstractDisplayInfo()
 
 void AbstractDisplayInfo::calendarImportError(const QString &log)
 {
-    Q_UNUSED(log);
+    Q_UNUSED(log)
 }
 
 void AbstractDisplayInfo::settingsImportError(const QString &log)
 {
-    Q_UNUSED(log);
+    Q_UNUSED(log)
 }
 
 void AbstractDisplayInfo::addressbookImportError(const QString &log)
 {
-    Q_UNUSED(log);
+    Q_UNUSED(log)
 }
 
 void AbstractDisplayInfo::filterImportError(const QString &log)
 {
-    Q_UNUSED(log);
+    Q_UNUSED(log)
 }
 
 void AbstractDisplayInfo::calendarImportInfo(const QString &log)
 {
-    Q_UNUSED(log);
+    Q_UNUSED(log)
 }
 
 void AbstractDisplayInfo::settingsImportInfo(const QString &log)
 {
-    Q_UNUSED(log);
+    Q_UNUSED(log)
 }
 
 void AbstractDisplayInfo::addressbookImportInfo(const QString &log)
 {
-    Q_UNUSED(log);
+    Q_UNUSED(log)
 }
 
 void AbstractDisplayInfo::filterImportInfo(const QString &log)
 {
-    Q_UNUSED(log);
+    Q_UNUSED(log)
 }
 
 QWidget *AbstractDisplayInfo::parentWidget() const
@@ -59,5 +59,5 @@ QWidget *AbstractDisplayInfo::parentWidget() const
 
 void AbstractDisplayInfo::initializeFilter(MailImporter::Filter &filter)
 {
-    Q_UNUSED(filter);
+    Q_UNUSED(filter)
 }
