@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef THUNDERBIRDADDRESSBOOK_H
-#define THUNDERBIRDADDRESSBOOK_H
+#pragma once
 
 #include "abstractaddressbook.h"
 #include <QDir>
@@ -24,4 +23,3 @@ private:
     QDir mDir;
 };
 
-#endif // THUNDERBIRDADDRESSBOOK_H
