@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TrojitaSettings_H
-#define TrojitaSettings_H
+#pragma once
 
 #include "abstractsettings.h"
 
@@ -26,4 +25,3 @@ private:
     QSettings *settings = nullptr;
 };
 
-#endif // ClawsMailSettings_H
